summaryrefslogtreecommitdiff
path: root/vcl/source/gdi/pdfwriter_impl.hxx
diff options
context:
space:
mode:
authorFridrich Strba <fridrich.strba@bluewin.ch>2011-02-03 16:55:17 -0700
committerFridrich Štrba <fridrich.strba@bluewin.ch>2011-02-04 01:10:15 +0100
commite99fcbe58ef7533da06ee4658a4ee2cde4df58ea (patch)
tree2dffe52eb92af74244d25f19613b1af187d9eab7 /vcl/source/gdi/pdfwriter_impl.hxx
parentfad7c8f3e0d0518b1a6411d53d5d0a3a43adf119 (diff)
Bulk move libs-gui to boost unordered containers
Diffstat (limited to 'vcl/source/gdi/pdfwriter_impl.hxx')
-rw-r--r--vcl/source/gdi/pdfwriter_impl.hxx12
1 files changed, 6 insertions, 6 deletions
diff --git a/vcl/source/gdi/pdfwriter_impl.hxx b/vcl/source/gdi/pdfwriter_impl.hxx
index 4e367ddbc169..8aacf749942e 100644
--- a/vcl/source/gdi/pdfwriter_impl.hxx
+++ b/vcl/source/gdi/pdfwriter_impl.hxx
@@ -51,7 +51,7 @@
#include <vector>
#include <map>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
#include <list>
#include <boost/shared_array.hpp>
@@ -439,8 +439,8 @@ public:
{}
};
- typedef std::hash_map< rtl::OString, SvMemoryStream*, rtl::OStringHash > PDFAppearanceStreams;
- typedef std::hash_map< rtl::OString, PDFAppearanceStreams, rtl::OStringHash > PDFAppearanceMap;
+ typedef boost::unordered_map< rtl::OString, SvMemoryStream*, rtl::OStringHash > PDFAppearanceStreams;
+ typedef boost::unordered_map< rtl::OString, PDFAppearanceStreams, rtl::OStringHash > PDFAppearanceMap;
struct PDFWidget : public PDFAnnotation
{
@@ -645,7 +645,7 @@ private:
bool m_bEmitStructure;
bool m_bNewMCID;
/* role map of struct tree root */
- std::hash_map< rtl::OString, rtl::OString, rtl::OStringHash >
+ boost::unordered_map< rtl::OString, rtl::OString, rtl::OStringHash >
m_aRoleMap;
/* contains all widgets used in the PDF
@@ -655,8 +655,8 @@ private:
std::map< sal_Int32, sal_Int32 > m_aRadioGroupWidgets;
/* used to store control id during beginControlAppearance/endControlAppearance */
sal_Int32 m_nCurrentControl;
- /* hash_map for field names, used to ensure unique field names */
- std::hash_map< rtl::OString, sal_Int32, rtl::OStringHash > m_aFieldNameMap;
+ /* boost::unordered_map for field names, used to ensure unique field names */
+ boost::unordered_map< rtl::OString, sal_Int32, rtl::OStringHash > m_aFieldNameMap;
/* contains Bitmaps for gradient functions until they are written
* to the file stream */